<?php
/**
 * Custom functions that act independently of the theme templates.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package Helena
 */

/**
 * Get Values from theme options, append default values if not present
 *
 * @param  [text] $value [option name].
 * @return [type]        [value of option].
 */
function helena_get_option( $value ) {
	return get_theme_mod( $value, helena_get_default_theme_options( $value ) );
}
add_filter( 'helena_get_option', 'helena_get_option' );

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function helena_body_classes( $classes ) {
	global $wp_query;

	// Get Page ID outside Loop.
	$page_id = $wp_query->get_queried_object_id();

	// Front page displays in Reading Settings.
	$page_for_posts = get_option( 'page_for_posts' );

	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Archive Content Image Layout.
	$content_layout = apply_filters( 'helena_get_option', 'content_layout' );

	if ( '' != $content_layout ) {
		$classes[] = $content_layout;
	}


	if ( class_exists( 'woocommerce' ) && is_woocommerce() ) {
		$classes[] = 'helena-woocommerce';
	}
	elseif ( 'excerpt-image-top' == $content_layout && ( is_archive() || is_home() ) ) {
		// Adds a class of helena-masonry to the body if Masonry is used.
		$classes[] = 'helena-masonry';
	}

	$layout = helena_get_theme_layout();

	switch ( $layout ) {
		case 'left-sidebar':
			$classes[] = 'layout-two-columns content-right';
		break;

		case 'right-sidebar':
			$classes[] = 'layout-two-columns content-left';
		break;

		case 'no-sidebar':
			$classes[] = 'layout-one-column no-sidebar content-width';
		break;

		case 'no-sidebar-one-column':
			$classes[] = 'layout-one-column no-sidebar fixed-width';
		break;

		case 'no-sidebar-full-width':
			$classes[] = 'layout-one-column no-sidebar full-width';
		break;
	}

	// Social Icon's Brand Color Options.
	$social_icon_brand_color = apply_filters( 'helena_get_option', 'social_menu_brand_color' );

	if ( 'hover' == $social_icon_brand_color ) {
		$classes[] = 'social-brand-hover';
	} elseif ( 'hover-static' == $social_icon_brand_color ) {
		$classes[] = 'social-brand-static';
	}

	// Search in Primary Menu
	$primary_menu_search = apply_filters( 'helena_get_option', 'disable_primary_search' );
	if ( '' == $primary_menu_search ) {
		$classes[] = 'primary-menu-search';
	}

	return $classes;
}
add_filter( 'body_class', 'helena_body_classes' );


if ( ! function_exists( 'helena_post_classes' ) ) :
	/**
	 * Adds Helena post classes to the array of post classes.
	 * used for supporting different content layouts
	 *
	 * @param  [array] $classes [body classes].
	 * @return [array] $classes [returned new body classes array]
	 *
	 * @since Helena Pro 1.0
	 */
	function helena_post_classes( $classes ) {
		// Getting Ready to load data from Theme Options Panel.
		$content_layout = apply_filters( 'helena_get_option', 'content_layout' );

		if ( is_archive() || is_home() ) {
			$classes[] = $content_layout;
		}

		return $classes;
	}
endif; // helena_post_classes.
add_filter( 'post_class', 'helena_post_classes' );


/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 *
 * @since Helena Pro 1.0
 */
function helena_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'footer-1' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'footer-2' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'footer-3' ) ) {
		$count++;
	}

	if ( is_active_sidebar( 'footer-4' ) ) {
		$count++;
	}

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
		case '4':
			$class = 'four';
			break;
	}

	if ( $class ) {
		echo 'class="' . esc_attr( $class ) . '"';
	}
}


if ( ! function_exists( 'helena_get_theme_layout' ) ) :
	/**
	 * Returns Theme Layout prioritizing the meta box layouts
	 *
	 * @uses  get_theme_mod
	 *
	 * @action wp_head
	 *
	 * @since Helena Pro 1.0
	 */
	function helena_get_theme_layout() {
		$id = '';

		// Set $id as Shop Page id for WooCommerce Pages excluding cart and checkout.
		if ( class_exists( 'woocommerce' ) && is_woocommerce() ) {
			$id = get_option( 'woocommerce_shop_page_id' );
		} else {
		    global $post, $wp_query;

		    // Front page displays in Reading Settings.
			$page_on_front  = get_option( 'page_on_front' );
			$page_for_posts = get_option( 'page_for_posts' );

			// Get Page ID outside Loop.
			$page_id = $wp_query->get_queried_object_id();

			// Blog Page or Front Page setting in Reading Settings.
			if ( $page_id == $page_for_posts || $page_id == $page_on_front ) {
		        $id = $page_id;
		    } elseif ( is_singular() ) {
		 		if ( is_attachment() ) {
					$id = $post->post_parent;
				} else {
					$id = $post->ID;
				}
			}
		}

		// Get appropriate metabox value of layout.
		if ( '' != $id ) {
			$layout = get_post_meta( $id, 'helena-layout-option', true );
		} else {
			$layout = 'default';
		}

		// Check empty and load default.
		if ( empty( $layout ) || 'default' == $layout ) {
			if ( class_exists( 'woocommerce' ) && ( is_woocommerce() || is_cart() || is_checkout() ) ) {
				$layout = apply_filters( 'helena_get_option', 'woocommerce_layout' );
			} elseif ( ! is_front_page() && ( is_single() || is_page() ) ) {
				$layout = apply_filters( 'helena_get_option', 'single_page_post_layout' );
			} else {
				$layout = apply_filters( 'helena_get_option', 'theme_layout' );
			}
		}

		return $layout;
	}
endif; //helena_get_theme_layout


if ( ! function_exists( 'helena_continue_reading' ) && ! is_admin() ) :
/**
 * Adds a "Continue reading" link to all instances of the_excerpt
 *
 * @return string The excerpt with a 'Continue reading' link appended.
 */
function helena_continue_reading( $the_excerpt ) {
	$more_tag_text	= apply_filters( 'helena_get_option', 'excerpt_more_text' );

	$the_excerpt = sprintf( '%1$s <div class="more-button"><a href="%2$s ">%3$s</a></div>',
		$the_excerpt,
		esc_url( get_permalink( get_the_ID() ) ),
		$more_tag_text
	);
	return $the_excerpt;
}
add_filter( 'the_excerpt', 'helena_continue_reading', 9 );
endif;

/**
 * Custom lenght of the excerpt depending on the post.
 */
function helena_excerpt_length( $length ) {
	// Getting data from Customizer Options
	$length	= apply_filters( 'helena_get_option', 'excerpt_length' );

	return $length;
}
add_filter( 'excerpt_length', 'helena_excerpt_length', 999 );

if ( ! function_exists( 'helena_excerpt_more' ) && ! is_admin() ) :
/**
 * Replaces "[...]" (appended to automatically generated excerpts) with a blank space.
 *
 */
function helena_excerpt_more( $more ) {
	return '';
}
add_filter( 'excerpt_more', 'helena_excerpt_more' );
endif;

if ( ! function_exists( 'helena_get_comment_section' ) ) :
	/**
	 * Comment Section
	 *
	 * @get comment setting from theme options and display comments sections accordingly
	 * @display comments_template
	 * @action helena_comment_section
	 *
	 * @since Helena Pro 1.0
	 */
	function helena_get_comment_section() {
		$comment_option = apply_filters( 'helena_get_option', 'comment_option' );

		if ( 'use-wordpress-setting' == $comment_option ) {
			if ( comments_open() || '0' != get_comments_number() )
				comments_template();
		}
		else if ( 'disable-in-pages' == $comment_option ) {
			if( ! is_page() ){
				if ( comments_open() || '0' != get_comments_number() ){
					comments_template();
				}
			}
		}
}
endif;
add_action( 'helena_comment_section', 'helena_get_comment_section', 10 );

if ( ! function_exists( 'helena_comment_form_fields' ) ) :
	/**
	 * Modify Comment Form Fields
	 *
	 * @uses comment_form_default_fields filter
	 * @since Helena Pro 1.0
	 */
	function helena_comment_form_fields( $fields ) {
		$disable_website_field = apply_filters( 'helena_get_option', 'disable_website_field' );

		if ( isset( $fields['url'] ) && $disable_website_field ) {
			unset( $fields['url'] );
		}

		return $fields;

	}
endif; //helena_comment_form_fields
add_filter( 'comment_form_default_fields', 'helena_comment_form_fields' );

if ( ! function_exists( 'helena_custom_css' ) ) :
/**
 * Enqueue Custom CSS
 *
 * @uses  get_theme_mod
 *
 * @action wp_head
 *
 * @since Helena Pro 1.0
 */
function helena_custom_css() {
	if ( ( !$output = get_transient( 'helena_custom_css' ) ) ) {
		echo '<!-- refreshing cache -->' . "\n";

		$defaults = helena_get_default_theme_options();

		// Typography (Font Family) Options
		$options['body_font']          = apply_filters( 'helena_get_option', 'body_font' );

		$options['title_font']         = apply_filters( 'helena_get_option', 'title_font' );

		$options['tagline_font']       = apply_filters( 'helena_get_option', 'tagline_font' );

		$options['content_title_font'] = apply_filters( 'helena_get_option', 'content_title_font' );

		$options['content_font']       = apply_filters( 'helena_get_option', 'content_font' );

		$options['headings_font']      = apply_filters( 'helena_get_option', 'headings_font' );


		$fonts = helena_avaliable_fonts();

		if ( $defaults['body_font'] != $options['body_font'] ) {
			$output	.= "body, button, input, select, textarea { font-family: " . $fonts [ $options['body_font' ] ] [ 'label'] . "; }" . "\n";
		}

		if ( $defaults['title_font'] != $options['title_font'] ) {
			$output	.= " .site-title { font-family: " . $fonts [ $options['title_font' ] ] [ 'label'] . "; }" . "\n";
		}

		if ( $defaults['tagline_font'] != $options['tagline_font'] ) {
			$output	.= " .site-description { font-family: " . $fonts [ $options['tagline_font' ] ] [ 'label'] . "; }" . "\n";
		}

		if ( $defaults['content_title_font'] != $options['content_title_font'] ) {
			$output	.= " .page-title, #main .entry-title, #main .entry-subtitle { font-family: " . $fonts [ $options['content_title_font' ] ] [ 'label'] . "; }" . "\n";
		}

		if ( $defaults['content_font'] != $options['content_font'] ) {
			$output	.= "#main .entry-content, #main .entry-summary { font-family: " . $fonts [ $options['content_font' ] ] [ 'label'] . "; }" . "\n";
		}

		if ( $defaults['headings_font'] != $options['headings_font'] ) {
			$output	.= "h1, h2, h3, h4, h5, h6 { font-family: " . $fonts [ $options['headings_font' ] ] [ 'label'] . "; }" . "\n";
		}

		$color_scheme = apply_filters( 'helena_get_option', 'color_scheme' );

		if ( 'dark' == $color_scheme ) {
			$defaults = helena_default_dark_color_options();
		} else {
			$defaults = helena_get_default_theme_options();
		}

		//Get all color options
		foreach ( $defaults as $key => $value) {
			$options[$key] = apply_filters( 'helena_get_option', $key );
		}

		$text_color = get_header_textcolor();

		if (  HEADER_TEXTCOLOR != '#' . $text_color ) {
			$output .= " .site-title a { color: #" .  esc_attr( $text_color ) . "; }" . "\n";
		}

		/* Basic Color Options */
		if ( $defaults['text_color'] != $options['text_color'] ) {
			$output .= "body, button, input, select, textarea { color: " . esc_attr( $options['text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['link_color'] != $options['link_color'] ) {
			$output	.= "a { color: " . esc_attr( $options['link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['link_hover_color'] != $options['link_hover_color'] ) {
			$output	.= "a:hover, a:focus, a:active { color: " . esc_attr( $options['link_hover_color'] ) . "; }" . "\n";
		}

		/* Header Color Options */
		if ( $defaults['header_background_color'] != $options['header_background_color'] ) {
			$output	.= "#masthead .wrapper { background-color: " . esc_attr( $options['header_background_color'] ) . "; }" . "\n";
		}

		if ( $defaults['site_title_hover_color'] != $options['site_title_hover_color'] ) {
			$output	.= ".site-title a:hover, .site-title a:focus { color: " . esc_attr( $options['site_title_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['tagline_color'] != $options['tagline_color'] ) {
			$output	.= ".site-description { color: " . esc_attr( $options['tagline_color'] ) . "; }" . "\n";
		}

		/* Header Image Color */
		if ( $defaults['header_image_background_color'] != $options['header_image_background_color'] ) {
			$output	.= "#header-featured-image .wrapper { background-color: " . esc_attr( $options['header_image_background_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_image_text_color'] != $options['header_image_text_color'] ) {
			$output	.= "#header-featured-image .entry-content { color: " . esc_attr( $options['header_image_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_image_content_wrapper_background_color'] != $options['header_image_content_wrapper_background_color'] ) {
			$rgba = helena_hex2rgb( $options['header_image_content_wrapper_background_color'] );

			$output	.= "#header-featured-image .entry-container { background-color: rgba( " . absint( $rgba['red'] ) . ", " . absint( $rgba['green'] ) . ", " . absint( $rgba['blue'] ) . ", 0.6 ); }" . "\n";
		}

		if ( $defaults['header_image_link_color'] != $options['header_image_link_color'] ) {
			$output	.= "#header-featured-image a { color: " . esc_attr( $options['header_image_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_image_link_hover_color'] != $options['header_image_link_hover_color'] ) {
			$output	.= "#header-featured-image a:hover, #header-featured-image a:focus { color: " . esc_attr( $options['header_image_link_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_image_title_color'] != $options['header_image_title_color'] ) {
			$output	.= "#header-featured-image .entry-title, #header-featured-image .entry-title a { color: " . esc_attr( $options['header_image_title_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_image_title_hover_color'] != $options['header_image_title_hover_color'] ) {
			$output	.= "#header-featured-image .entry-title:hover, #header-featured-image .entry-title:focus, #header-featured-image .entry-title a:hover, #header-featured-image .entry-title a:focus { color: " . esc_attr( $options['header_image_title_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_image_button_background_color'] != $options['header_image_button_background_color' ] || $defaults['header_image_button_border_color'] != $options['header_image_button_border_color' ] || $defaults['header_image_button_text_color'] != $options['header_image_button_text_color'] ) {
			$output	.= "#header-featured-image .more-button a { background-color: " . $options['header_image_button_background_color' ] . "; border-color: " . $options['header_image_button_border_color' ] . "; color: " . esc_attr( $options['header_image_button_text_color'] ) . ";  }" . "\n";
		}

		if ( $defaults['header_image_button_hover_background_color'] != $options['header_image_button_hover_background_color' ] || $defaults['header_image_button_hover_border_color'] != $options['header_image_button_hover_border_color' ] || $defaults['header_image_button_hover_text_color'] != $options['header_image_button_hover_text_color'] ) {
			$output	.= "#header-featured-image .more-button a:hover, #header-featured-image .more-button a:focus { background-color: " . $options['header_image_button_hover_background_color' ] . "; border-color: " . $options['header_image_button_hover_border_color' ] . "; color: " . esc_attr( $options['header_image_button_hover_text_color'] ) . ";  }" . "\n";
		}

		/* Breadcrumb Color Options */
		if ( $defaults['breadcrumb_background_color'] != $options['breadcrumb_background_color'] || $defaults['breadcrumb_text_color'] != $options['breadcrumb_text_color']  ) {
			$output	.= "#breadcrumb-list .wrapper { background-color: " . esc_attr( $options['breadcrumb_background_color'] ) . "; color: " . esc_attr( $options['breadcrumb_text_color'] ) . " }" . "\n";
		}

		if ( $defaults['breadcrumb_link_color'] != $options['breadcrumb_link_color'] ) {
			$output	.= "#breadcrumb-list a { color: " . esc_attr( $options['breadcrumb_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['breadcrumb_link_hover_color'] != $options['breadcrumb_link_hover_color'] ) {
			$output	.= "#breadcrumb-list a:hover, #breadcrumb-list a:focus { color: " . esc_attr( $options['breadcrumb_link_hover_color'] ) . "; }" . "\n";
		}

		/* Content Color Options */
		if ( $defaults['content_wrapper_background_color'] != $options['content_wrapper_background_color'] ) {
			$output	.= "#content { background-color: " . esc_attr( $options['content_wrapper_background_color'] ) . "; }" . "\n";
		}

		if ( $defaults['content_wrapper_background_color'] != $options['content_wrapper_background_color'] ) {
			$output	.= " .site-content .wrapper { background-color: " . esc_attr( $options['content_wrapper_background_color'] ) . "; }" . "\n";
		}

		if ( $defaults['content_background_color'] != $options['content_background_color'] ) {
			$output	.= "#main { background-color: " . esc_attr( $options['content_background_color'] ) . "; }" . "\n";
		}

		if ( $defaults['alternate_post_background_color'] != $options['alternate_post_background_color'] ) {
			$output	.= " .grid-item:nth-child(2n+0) { background-color: " . esc_attr( $options['alternate_post_background_color'] ) . "; }" . "\n";
		}

		if ( $defaults['content_title_color'] != $options['content_title_color'] ) {
			$output	.= " .page-title, #main .entry-title, #main .entry-title a, #main .entry-subtitle, #main .entry-subtitle a { color: " . esc_attr( $options['content_title_color'] ) . "; }" . "\n";
		}

		if ( $defaults['content_title_hover_color'] != $options['content_title_hover_color'] ) {
			$output	.= "#main .entry-title a:hover, #main .entry-title a:focus, #main .entry-subtitle a:hover, #main .entry-subtitle a:focus { color: " . esc_attr( $options['content_title_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['content_meta_color'] != $options['content_meta_color'] ) {
			$output	.= "#main .entry-meta, #main .entry-meta a, .entry-footer, .entry-footer a { color: " . esc_attr( $options['content_meta_color'] ) . "; }" . "\n";
		}

		if ( $defaults['content_meta_hover_color'] != $options['content_meta_hover_color'] ) {
			$output	.= "#main .entry-meta a:hover, #main .entry-meta a:focus, .entry-footer a:hover, .entry-footer a:focus { color: " . esc_attr( $options['content_meta_hover_color'] ) . "; }" . "\n";
		}

		// Social Menu Color
		if ( ( $defaults['social_menu_color'] != $options['social_menu_color' ] ) || ( $defaults['social_menu_border_color'] != $options['social_menu_border_color' ] ) ) {
			$output	.= " .social-menu ul a, .sidebar-primary .social-menu ul a { border-color: " . $options['social_menu_border_color' ] . "; color: " . esc_attr( $options['social_menu_color'] ) . "; }" . "\n";
		}

		if ( ( $defaults['social_menu_hover_color'] != $options['social_menu_hover_color' ] ) || ( $defaults['social_menu_hover_border_color'] != $options['social_menu_hover_border_color' ] ) ) {
			$output	.= " .social-menu ul a:hover, .social-menu ul a:focus, .sidebar-primary .social-menu ul a:hover, .sidebar-primary .social-menu ul a:focus { border-color: " . $options['social_menu_hover_border_color' ] . "; color: " . esc_attr( $options['social_menu_hover_color'] ) . "; }" . "\n";
		}

		//Sidebar Color Options
		if ( $defaults['sidebar_background_color'] != $options['sidebar_background_color'] ) {
			$output	.= " .sidebar-primary { background-color: " . esc_attr( $options['sidebar_background_color'] ) . "; }" . "\n";
		}

		if ( $defaults['sidebar_widget_title_color'] != $options['sidebar_widget_title_color'] ) {
			$output	.= " .sidebar-primary .widget-title, .sidebar-primary .widget-title a { color: " . esc_attr( $options['sidebar_widget_title_color'] ) . "; }" . "\n";
		}

		if ( $defaults['sidebar_widget_text_color'] != $options['sidebar_widget_text_color'] ) {
			$output	.= " .sidebar-primary .widget { color: " . esc_attr( $options['sidebar_widget_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['sidebar_widget_link_color'] != $options['sidebar_widget_link_color'] ) {
			$output	.= " .sidebar-primary .widget a, .sidebar-primary .widget .entry-meta a { color: " . esc_attr( $options['sidebar_widget_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['sidebar_widget_link_hover_color'] != $options['sidebar_widget_link_hover_color'] ) {
			$output	.= " .sidebar-primary .widget a:hover, .sidebar-primary .widget a:focus, .sidebar-primary .widget .entry-meta a:hover, .sidebar-primary .widget .entry-meta a:focus { color: " . esc_attr( $options['sidebar_widget_link_hover_color'] ) . "; }" . "\n";
		}

		//Pagination Color Options
		if ( ( $defaults['pagination_background_color'] != $options['pagination_background_color' ] ) || ( $defaults['pagination_link_color'] != $options['pagination_link_color' ] ) ) {
			$output	.= "#infinite-handle span, .nav-previous a, .nav-next a, .pagination .page-numbers, .navigation .wp-pagenavi a, .navigation .wp-pagenavi span, .page-links a span { background-color: " . $options['pagination_background_color' ] . "; color: " . esc_attr( $options['pagination_link_color'] ) . "; }" . "\n";
		}

		if ( ( $defaults['pagination_hover_background_color'] != $options['pagination_hover_background_color' ] ) || ( $defaults['pagination_hover_link_color'] != $options['pagination_hover_link_color' ] ) ) {
			$output	.= "#infinite-handle span:hover, #infinite-handle span:focus, .nav-previous a:hover, .nav-next a:hover, .nav-previous a:focus, .nav-next a:focus, .pagination .page-numbers:hover, .pagination .page-numbers:focus, .pagination .page-numbers.current, .navigation .wp-pagenavi a:hover, .navigation .wp-pagenavi a:focus, .navigation .wp-pagenavi span.current, .page-links span, .page-links a:hover span, .page-links a:focus span { background-color: " . $options['pagination_hover_background_color' ] . "; color: " . esc_attr( $options['pagination_hover_link_color'] ) . "; }" . "\n";
		}

			if ( $defaults['pagination_text_color'] != $options['pagination_text_color'] ) {
			$output	.= " .page-links .page-links-title, .navigation .wp-pagenavi span.pages { color: " . esc_attr( $options['pagination_text_color'] ) . "; }" . "\n";
		}

		//Footer Color Options
		if ( ( $defaults['footer_background_color'] != $options['footer_background_color' ] ) || ( $defaults['footer_text_color'] != $options['footer_text_color'] ) ) {
			$output	.= " .site-footer .wrapper { background-color: " . $options['footer_background_color' ] . "; color: " . esc_attr( $options['footer_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['footer_text_color'] != $options['footer_text_color'] ) {
			$output	.= " .site-footer, .site-footer .site-description { color: " . esc_attr( $options['footer_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['footer_link_color'] != $options['footer_link_color'] ) {
			$output	.= " .site-footer a { color: " . esc_attr( $options['footer_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['footer_link_hover_color'] != $options['footer_link_hover_color'] ) {
			$output	.= " .site-footer a:hover, .site-footer a:focus { color: " . esc_attr( $options['footer_link_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['footer_sidebar_area_background_color'] != $options['footer_sidebar_area_background_color' ] ) {
			$output	.= "#supplementary .wrapper { background-color: " . $options['footer_sidebar_area_background_color' ] . "; }" . "\n";
		}

		if ( $defaults['footer_widget_title_color'] != $options['footer_widget_title_color'] ) {
			$output	.= "#supplementary .widget-title, #supplementary .widget-title a { color: " . esc_attr( $options['footer_widget_title_color'] ) . "; }" . "\n";
		}

		if ( $defaults['footer_widget_text_color'] != $options['footer_widget_text_color'] ) {
			$output	.= "#supplementary .widget { color: " . esc_attr( $options['footer_widget_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['footer_widget_link_color'] != $options['footer_widget_link_color'] ) {
			$output	.= "#supplementary .widget a { color: " . esc_attr( $options['footer_widget_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['footer_widget_link_hover_color'] != $options['footer_widget_link_hover_color'] ) {
			$output	.= "#supplementary .widget a:hover, #supplementary .widget a:focus { color: " . esc_attr( $options['footer_widget_link_hover_color'] ) . "; }" . "\n";
		}

		//Promotion Headline Color Options
		if ( $defaults['promotion_headline_background_color'] != $options['promotion_headline_background_color' ] || $defaults['promotion_headline_text_color'] != $options['promotion_headline_text_color'] ) {
			$output	.= "#promotion-message .wrapper { background-color: " . $options['promotion_headline_background_color' ] . "; color: " . esc_attr( $options['promotion_headline_text_color'] ) . ";  }" . "\n";
		}


		if ( $defaults['promotion_headline_link_color'] != $options['promotion_headline_link_color'] ) {
			$output	.= "#promotion-message a { color: " . esc_attr( $options['promotion_headline_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['promotion_headline_link_hover_color'] != $options['promotion_headline_link_hover_color'] ) {
			$output	.= "#promotion-message a:hover, #promotion-message a:focus { color: " . esc_attr( $options['promotion_headline_link_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['promotion_headline_button_background_color'] != $options['promotion_headline_button_background_color' ] || $defaults['promotion_headline_button_border_color'] != $options['promotion_headline_button_border_color' ] || $defaults['promotion_headline_button_link_color'] != $options['promotion_headline_button_link_color'] ) {
			$output	.= "#promotion-message .more-button a { background-color: " . $options['promotion_headline_button_background_color' ] . "; border-color: " . $options['promotion_headline_button_border_color' ] . "; color: " . esc_attr( $options['promotion_headline_button_link_color'] ) . ";  }" . "\n";
		}

		if ( $defaults['promotion_headline_button_hover_background_color'] != $options['promotion_headline_button_hover_background_color' ] || $defaults['promotion_headline_button_hover_border_color'] != $options['promotion_headline_button_hover_border_color' ] || $defaults['promotion_headline_button_hover_link_color'] != $options['promotion_headline_button_hover_link_color'] ) {
			$output	.= "#promotion-message .more-button a:hover, #promotion-message .more-button a:focus { background-color: " . $options['promotion_headline_button_hover_background_color' ] . "; border-color: " . $options['promotion_headline_button_hover_border_color' ] . "; color: " . esc_attr( $options['promotion_headline_button_hover_link_color'] ) . ";  }" . "\n";
		}

		//Scrollup Color Options
		if ( $defaults['scrollup_background_color'] != $options['scrollup_background_color' ] || $defaults['scrollup_border_color'] != $options['scrollup_border_color' ] || $defaults['scrollup_text_color'] != $options['scrollup_text_color'] ) {
			$output	.= "#scrollup { background-color: " . $options['scrollup_background_color' ] . "; border-color: " . $options['scrollup_border_color' ] . "; color: " . esc_attr( $options['scrollup_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['scrollup_hover_background_color'] != $options['scrollup_hover_background_color' ] || $defaults['scrollup_hover_border_color'] != $options['scrollup_hover_border_color' ] || $defaults['scrollup_hover_text_color'] != $options['scrollup_hover_text_color'] ) {
			$output	.= "#scrollup:hover, #scrollup:focus { background-color: " . $options['scrollup_hover_background_color' ] . "; border-color: " . $options['scrollup_hover_border_color' ] . "; color: " . esc_attr( $options['scrollup_hover_text_color'] ) . "; }" . "\n";
		}

		/* Header Highlight Headline Color */
		if ( $defaults['header_highlight_background_color'] != $options['header_highlight_background_color'] || $defaults['header_highlight_text_color'] != $options['header_highlight_text_color']  ) {
			$output	.= "#header-highlights-content .wrapper { background-color: " . esc_attr( $options['header_highlight_background_color'] ) . "; color: " . esc_attr( $options['header_highlight_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_headline_color'] != $options['header_highlight_headline_color'] ) {
			$output	.= "#header-highlights-content .section-title, #header-highlights-content .section-title { color: " . esc_attr( $options['header_highlight_headline_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_headline_hover_color'] != $options['header_highlight_headline_hover_color'] ) {
			$output	.= "#header-highlights-content .section-title:hover, #header-highlights-content .section-title:focus { color: " . esc_attr( $options['header_highlight_headline_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_content_background_color'] != $options['header_highlight_content_background_color'] ) {
			$output	.= "#header-highlights-content .hentry { background-color: " . esc_attr( $options['header_highlight_content_background_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_link_color'] != $options['header_highlight_link_color'] ) {
			$output	.= "#header-highlights-content a { color: " . esc_attr( $options['header_highlight_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_link_hover_color'] != $options['header_highlight_link_hover_color'] ) {
			$output	.= "#header-highlights-content a:hover, #header-highlights-content a:focus { color: " . esc_attr( $options['header_highlight_link_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_title_color'] != $options['header_highlight_title_color'] ) {
			$output	.= "#header-highlights-content .entry-title, #header-highlights-content .entry-title a { color: " . esc_attr( $options['header_highlight_title_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_title_hover_color'] != $options['header_highlight_title_hover_color'] ) {
			$output	.= "#header-highlights-content .hentry .entry-title a:hover, #header-highlights-content .hentry .entry-title a:focus { color: " . esc_attr( $options['header_highlight_title_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_meta_color'] != $options['header_highlight_meta_color'] ) {
			$output	.= "#header-highlights-content .entry-meta a { color: " . esc_attr( $options['header_highlight_meta_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_meta_hover_color'] != $options['header_highlight_meta_hover_color'] ) {
			$output	.= "#header-highlights-content .hentry .entry-title a:hover, #header-highlights-content .hentry .entry-title a:focus, #header-highlights-content .hentry .entry-meta a:hover, #header-highlights-content .hentry .entry-meta a:focus { color: " . esc_attr( $options['header_highlight_meta_hover_color'] ) . "; }" . "\n";
		}

		// Custom CSS for header highlight small content
		$header_highlight_small = '';
		if ( $defaults['header_highlight_small_title_color'] != $options['header_highlight_small_title_color'] ) {
			$header_highlight_small	.= "#header-highlights-content .small-featured-image .entry-title, #header-highlights-content .small-featured-image .entry-title a { color: " . esc_attr( $options['header_highlight_small_title_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_small_title_hover_color'] != $options['header_highlight_small_title_hover_color'] ) {
			$header_highlight_small	.= "#header-highlights-content .small-featured-image .entry-title a:hover, #header-highlights-content .small-featured-image .entry-title a:focus { color: " . esc_attr( $options['header_highlight_small_title_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_small_meta_color'] != $options['header_highlight_small_meta_color'] ) {
			$header_highlight_small	.= "#header-highlights-content .small-featured-image .entry-meta a { color: " . esc_attr( $options['header_highlight_small_meta_color'] ) . "; }" . "\n";
		}

		if ( $defaults['header_highlight_small_meta_hover_color'] != $options['header_highlight_small_meta_hover_color'] ) {
			$header_highlight_small	.= "#header-highlights-content .small-featured-image .entry-meta a:hover, #header-highlights-content .small-featured-image .entry-meta a:focus { color: " . esc_attr( $options['header_highlight_small_meta_hover_color'] ) . "; }" . "\n";
		}

		if ( '' != $header_highlight_small ) {
			$output .= "@media screen and (min-width: 910px) {\n" . $header_highlight_small . "\n}";
		}

		/* Slider Color Options */
		if ( $defaults['slider_background_color'] != $options['slider_background_color'] ) {
			$output	.= "#feature-slider .wrapper { background-color: " . esc_attr( $options['slider_background_color'] ) . "; }" . "\n";
		}

		if ( $defaults['slider_text_color'] != $options['slider_text_color'] ) {
			$output	.= "#feature-slider .entry-content, #feature-slider .entry-summary { color: " . esc_attr( $options['slider_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['slider_content_wrapper_background_color'] != $options['slider_content_wrapper_background_color'] ) {
			$rgba = helena_hex2rgb( $options['slider_content_wrapper_background_color'] );

			$output	.= "#feature-slider .entry-container { background-color: rgba( " . absint( $rgba['red'] ) . ", " . absint( $rgba['green'] ) . ", " . absint( $rgba['blue'] ) . ", 0.6 ); }" . "\n";
		}

		if ( $defaults['slider_link_color'] != $options['slider_link_color'] ) {
			$output	.= "#feature-slider a { color: " . esc_attr( $options['slider_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['slider_link_hover_color'] != $options['slider_link_hover_color'] ) {
			$output	.= "#feature-slider a:hover, #feature-slider a:focus { color: " . esc_attr( $options['slider_link_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['slider_title_color'] != $options['slider_title_color'] ) {
			$output	.= "#feature-slider .entry-title, #feature-slider .entry-title a { color: " . esc_attr( $options['slider_title_color'] ) . "; }" . "\n";
		}

		if ( $defaults['slider_title_hover_color'] != $options['slider_title_hover_color'] ) {
			$output	.= "#feature-slider .entry-title a:hover, #feature-slider .entry-title a:focus { color: " . esc_attr( $options['slider_title_hover_color'] ) . "; }" . "\n";
		}

		if ( ( $defaults['slider_button_background_color'] != $options['slider_button_background_color' ] ) || ( $defaults['slider_button_text_color'] != $options['slider_button_text_color' ] ) || ( $defaults['slider_button_border_color'] != $options['slider_button_border_color'] ) ) {
			$output	.= "#feature-slider .more-button a { background-color: " . $options['slider_button_background_color' ] . "; border-color: " . $options['slider_button_border_color' ] . "; color: " . esc_attr( $options['slider_button_text_color'] ) . "; }" . "\n";
		}

		if ( ( $defaults['slider_button_hover_background_color'] != $options['slider_button_hover_background_color' ] ) || ( $defaults['slider_button_hover_border_color'] != $options['slider_button_hover_border_color' ] ) || ( $defaults['slider_button_hover_text_color'] != $options['slider_button_hover_text_color'] ) ) {
			$output	.= "#feature-slider .more-button a:hover, #feature-slider .more-button a:focus { background-color: " . $options['slider_button_hover_background_color' ] . "; border-color: " . $options['slider_button_hover_border_color' ] . "; color: " . esc_attr( $options['slider_button_hover_text_color'] ) . "; }" . "\n";
		}

		/* Hero Content Color Options */
		if ( $defaults['hero_content_background_color'] != $options['hero_content_background_color' ] || $defaults['hero_content_text_color'] != $options['hero_content_text_color'] ) {
			$output	.= "#hero-section .wrapper { background-color: " . $options['hero_content_background_color' ] . "; color: " . esc_attr( $options['hero_content_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['hero_content_title_color'] != $options['hero_content_title_color'] ) {
			$output	.= "#hero-section .entry-title, #hero-section .entry-title a { color: " . esc_attr( $options['hero_content_title_color'] ) . "; }" . "\n";
		}

		if ( $defaults['hero_content_title_hover_color'] != $options['hero_content_title_hover_color'] ) {
			$output	.= "#hero-section .entry-title a:hover, #hero-section .entry-title a:focus { color: " . esc_attr( $options['hero_content_title_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['hero_content_link_color'] != $options['hero_content_link_color'] ) {
			$output	.= "#hero-section a { color: " . esc_attr( $options['hero_content_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['hero_content_link_hover_color'] != $options['hero_content_link_hover_color'] ) {
			$output	.= "#hero-section a:hover, #hero-section a:focus { color: " . esc_attr( $options['hero_content_link_hover_color'] ) . "; }" . "\n";
		}

		/* Featured Content Color Options */
		if ( $defaults['featured_content_background_color'] != $options['featured_content_background_color' ] || $defaults['featured_content_text_color'] != $options['featured_content_text_color'] ) {
			$output	.= "#featured-content .wrapper, #featured-content .hentry { background-color: " . $options['featured_content_background_color' ] . "; color: " . esc_attr( $options['featured_content_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['featured_content_headline_color'] != $options['featured_content_headline_color'] ) {
			$output	.= "#featured-content .section-title { color: " . esc_attr( $options['featured_content_headline_color'] ) . "; }" . "\n";
		}

		if ( $defaults['featured_content_sub_headline_color'] != $options['featured_content_sub_headline_color'] ) {
			$output	.= ".featured-heading-wrap { color: " . esc_attr( $options['featured_content_sub_headline_color'] ) . "; }" . "\n";
		}

		if ( $defaults['featured_content_title_color'] != $options['featured_content_title_color'] ) {
			$output	.= "#featured-content .entry-title, #featured-content .entry-title a { color: " . esc_attr( $options['featured_content_title_color'] ) . "; }" . "\n";
		}

		if ( $defaults['featured_content_title_hover_color'] != $options['featured_content_title_hover_color'] ) {
			$output	.= "#featured-content .entry-title a:hover, #featured-content .entry-title a:focus { color: " . esc_attr( $options['featured_content_title_hover_color'] ) . "; }" . "\n";
		}

		if ( $defaults['featured_content_link_color'] != $options['featured_content_link_color'] ) {
			$output	.= "#featured-content .wrapper a { color: " . esc_attr( $options['featured_content_link_color'] ) . "; }" . "\n";
		}

		if ( $defaults['featured_content_link_hover_color'] != $options['featured_content_link_hover_color'] ) {
			$output	.= "#featured-content .wrapper a:hover, #featured-content .wrapper a:focus { color: " . esc_attr( $options['featured_content_link_hover_color'] ) . "; }" . "\n";
		}

		/* Primary Menu Color */
		if ( $defaults['menu_background_color'] != $options['menu_background_color'] || $defaults['menu_color'] != $options['menu_color'] ) {
			$output	.= ".main-navigation a { background-color: " . esc_attr( $options['menu_background_color'] ) ."; color: " . esc_attr( $options['menu_color'] ) . "; }" . "\n";
		}

		if ( $defaults['menu_hover_active_background_color'] != $options['menu_hover_active_background_color'] || $defaults['menu_hover_active_text_color'] != $options['menu_hover_active_text_color'] ) {
			$output	.= ".main-navigation .menu li a:hover, .main-navigationy .menu li a:focus, .main-navigation .menu li:hover > a, .main-navigation .menu li:focus > a, .main-navigation .menu .current-menu-item > a, .main-navigation .menu .current-menu-ancestor > a, .main-navigation .menu .current_page_item > a, .main-navigation .menu .current_page_ancestor > a  { background-color: " . esc_attr( $options['menu_hover_active_background_color'] ) ."; color: " . esc_attr( $options['menu_hover_active_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['sub_menu_background_color'] != $options['sub_menu_background_color'] || $defaults['sub_menu_border_color'] != $options['sub_menu_border_color'] ) {
			$output	.= ".main-navigation .menu .sub-menu li, .main-navigation .menu .children li { background-color: " . esc_attr( $options['sub_menu_background_color'] ) ."; border=color: " . esc_attr( $options['sub_menu_border_color'] ) . "; }" . "\n";
		}

		if ( $defaults['sub_menu_hover_background_color'] != $options['sub_menu_hover_background_color'] || $defaults['sub_menu_hover_border_color'] != $options['sub_menu_hover_border_color'] ) {
			$output	.= ".main-navigation .menu .sub-menu li:hover, .main-navigation .menu .sub-menu li:focus, .main-navigation .menu .children li:hover, .main-navigation .menu .children li:focus { background-color: " . esc_attr( $options['sub_menu_hover_background_color'] ) ."; border=color: " . esc_attr( $options['sub_menu_hover_border_color'] ) . "; }" . "\n";
		}

		if ( $defaults['sub_menu_text_color'] != $options['sub_menu_text_color'] ) {
			$output	.= ".main-navigation .menu .sub-menu a, .main-navigation .menu .children a { color: " . esc_attr( $options['sub_menu_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['sub_menu_hover_text_color'] != $options['sub_menu_hover_text_color'] ) {
			$output	.= ".main-navigation .menu .sub-menu a:hover, .main-navigation .menu .sub-menu a:focus, .main-navigation .menu .children a:hover, .main-navigation.menu .children a:focus { color: " . esc_attr( $options['sub_menu_hover_text_color'] ) . "; }" . "\n";
		}

		/* Mobile Menu Color */
		if ( ( $defaults['mobile_menu_button_background_color'] != $options['mobile_menu_button_background_color' ] ) || ( $defaults['mobile_menu_button_text_color'] != $options['mobile_menu_button_text_color' ] ) || ( $defaults['mobile_menu_button_border_color'] != $options['mobile_menu_button_border_color'] ) ) {
			$output	.= ".menu-toggle { background-color: " . $options['mobile_menu_button_background_color' ] . "; border-color: " . $options['mobile_menu_button_border_color' ] . "; color: " . esc_attr( $options['mobile_menu_button_text_color'] ) . "; }" . "\n";
		}

		if ( ( $defaults['mobile_menu_hover_button_background_color'] != $options['mobile_menu_hover_button_background_color' ] ) || ( $defaults['mobile_menu_hover_button_text_color'] != $options['mobile_menu_hover_button_text_color' ] ) || ( $defaults['mobile_menu_hover_button_border_color'] != $options['mobile_menu_hover_button_border_color'] ) ) {
			$output	.= ".menu-toggle:hover, .menu-toggle:focus { background-color: " . $options['mobile_menu_hover_button_background_color' ] . "; border-color: " . $options['mobile_menu_hover_button_border_color' ] . "; color: " . esc_attr( $options['mobile_menu_hover_button_text_color'] ) . "; }" . "\n";
		}

		if ( ( $defaults['mobile_menu_focus_button_background_color'] != $options['mobile_menu_focus_button_background_color' ] ) || ( $defaults['mobile_menu_focus_button_text_color'] != $options['mobile_menu_focus_button_text_color' ] ) || ( $defaults['mobile_menu_focus_button_border_color'] != $options['mobile_menu_focus_button_border_color'] ) ) {
			$output	.= ".menu-toggle.toggled-on, .menu-toggle.toggled-on:hover, .menu-toggle.toggled-on:focus { background-color: " . $options['mobile_menu_focus_button_background_color' ] . "; border-color: " . $options['mobile_menu_focus_button_border_color' ] . "; color: " . esc_attr( $options['mobile_menu_focus_button_text_color'] ) . "; }" . "\n";
		}

		if ( $defaults['mobile_menu_dropdown_toggle_background_color'] != $options['mobile_menu_dropdown_toggle_background_color'] || $defaults['mobile_menu_dropdown_toggle_color'] != $options['mobile_menu_dropdown_toggle_color'] ) {
			$output	.= ".dropdown-toggle { background-color: " . esc_attr( $options['mobile_menu_dropdown_toggle_background_color'] ) ."; color: " . esc_attr( $options['mobile_menu_dropdown_toggle_color'] ) . "; }" . "\n";
		}

		if ( $defaults['mobile_menu_dropdown_toggle_background_hover_color'] != $options['mobile_menu_dropdown_toggle_background_hover_color'] || $defaults['mobile_menu_dropdown_toggle_hover_color'] != $options['mobile_menu_dropdown_toggle_hover_color'] ) {
			$output	.= ".dropdown-toggle:hover, .dropdown-toggle:focus  { background-color: " . esc_attr( $options['mobile_menu_dropdown_toggle_background_hover_color'] ) ."; color: " . esc_attr( $options['mobile_menu_dropdown_toggle_hover_color'] ) . "; }" . "\n";
		}

		/* Custom CSS Option */
		$custom_css = apply_filters( 'helena_get_option', 'custom_css' );

		if ( $custom_css ) {
			$output	.= $custom_css . "\n";
		}

		if ( '' != $output ){
			$output = '<!-- '.get_bloginfo('name').' inline CSS Styles -->' . "\n" . '<style type="text/css" media="screen">' . "\n" . $output;

			$output .= '</style>' . "\n";
		}

		set_transient( 'helena_custom_css', $output, 86940 );
	}
	echo $output;
}
endif; //helena_custom_css
add_action( 'wp_head', 'helena_custom_css', 101 );

if ( ! function_exists( 'helena_rss_redirect' ) ) :
	/**
	 * Redirect WordPress Feeds To FeedBurner
	 *
	 * @action template_redirect
	 *
	 * @since Helena Pro 1.0
	 */
	function helena_rss_redirect() {
		$feed_redirect = apply_filters( 'helena_get_option', 'feed_redirect' );

	    if ( $feed_redirect ) {
			$url = 'Location: '. $feed_redirect;

			if ( is_feed() && !preg_match('/feedburner|feedvalidator/i', $_SERVER['HTTP_USER_AGENT'] ) ) {
				header( esc_url( $url ) );
				header('HTTP/1.1 302 Temporary Redirect');
			}
		}
	}
endif; //helena_rss_redirect
add_action( 'template_redirect', 'helena_rss_redirect' );

/**
 * Alter the query for the main loop in homepage
 *
 * @action pre_get_posts
 *
 * @since Helena Pro 1.0
 */
function helena_alter_home( $query ){
	if ( $query->is_main_query() && $query->is_home() ) {
		$cats                = (array) apply_filters( 'helena_get_option', 'front_page_category' );
		$quantity            = apply_filters( 'helena_get_option', 'featured_slider_number' );
		$exclude_slider_post = apply_filters( 'helena_get_option', 'exclude_slider_post' );

	    if ( $exclude_slider_post ) {
			$post_list	= array();	// list of valid post ids

			for( $i = 1; $i <= $quantity; $i++ ){
				$id = apply_filters( 'helena_get_option', 'featured_slider_post_' . $i );
				if ( $id ){
					$post_list[] = $id;
				}

			}

			if ( !empty( $post_list ) ) {
				$query->query_vars['post__not_in'] = $post_list;
			}
		}

	    if ( is_array( $cats ) && !in_array( '0', $cats ) ) {
			$query->query_vars['category__in'] =  $cats;
		}
	}
}
add_action( 'pre_get_posts','helena_alter_home' );

if ( ! function_exists( 'helena_footer_content' ) ) :
	/**
	 * Return footer content
	 *
	 * @since Helena Pro 1.0
	 *
	 */
	function helena_footer_content() {
		if ( ( !$output = get_transient( 'helena_footer_content' ) ) ) {
			$footer_content = apply_filters( 'helena_get_option', 'footer_content' );

			if ( empty( $footer_content ) ) {
				return;
			}

			$search = array( '[the-year]', '[site-link]' );

	        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

	        $footer_content = str_replace( $search, $replace, $footer_content );

	    	$output =  wp_kses_post( $footer_content );

	    	set_transient( 'helena_footer_content', $output, 86940 );
	    }

    	echo $output;
	}
endif;
add_action( 'helena_footer', 'helena_footer_content', 50 );

if ( ! function_exists( 'helena_scrollup' ) ) {
	/**
	 * This function loads Scroll Up Navigation
	 */
	function helena_scrollup() {
		$disable_scrollup = apply_filters( 'helena_get_option', 'disable_scrollup' );

		if ( $disable_scrollup ) {
			//Bail if scroll up is disabled
			return;
		}

		echo '<a href="#masthead" id="scrollup"><span class="screen-reader-text">' . esc_html__( 'Scroll Up', 'helena-pro' ) . '</span></a>' ;
	}
}
add_action( 'wp_footer', 'helena_scrollup', 10 );

/**
 * Return registered image sizes.
 *
 * Return a two-dimensional array of just the additionally registered image sizes, with width, height and crop sub-keys.
 *
 * @since Helena Pro 1.0
 *
 * @global array $_wp_additional_image_sizes Additionally registered image sizes.
 *
 * @return array Two-dimensional, with width, height and crop sub-keys.
 */
function helena_get_additional_image_sizes() {
	global $_wp_additional_image_sizes;

	if ( $_wp_additional_image_sizes ) {
		return $_wp_additional_image_sizes;
	}

	return array();
}

if ( ! function_exists( 'helena_get_meta' ) ) :
	/**
	 * Returns HTML with meta information for the categories, tags, date and author.
	 *
	 * @param [boolean] $hide_category Adds screen-reader-text class to category meta if true
	 * @param [boolean] $hide_tags Adds screen-reader-text class to tag meta if true
	 * @param [boolean] $hide_posted_by Adds screen-reader-text class to date meta if true
	 * @param [boolean] $hide_author Adds screen-reader-text class to author meta if true
	 *
	 * @since Helena Pro 1.0
	 */
	function helena_get_meta( $hide_category = false, $hide_tags = false, $hide_posted_by = false, $hide_author = false ) {
		$output = '<p class="entry-meta">';

		if ( 'post' == get_post_type() ) {

			$class = $hide_category ? 'screen-reader-text' : '';

			$categories_list = get_the_category_list( _x( ', ', 'Used between list items, there is a space after the comma.', 'helena-pro' ) );
			if ( $categories_list && helena_categorized_blog() ) {
				$output .= sprintf( '<span class="cat-links ' . $class . '">%1$s%2$s</span>',
					sprintf( _x( '<span class="screen-reader-text">Categories</span>', 'Used before category names.', 'helena-pro' ) ),
					$categories_list
				);
			}

			$class = $hide_tags ? 'screen-reader-text' : '';

			$tags_list = get_the_tag_list( '', _x( ', ', 'Used between list items, there is a space after the comma.', 'helena-pro' ) );
			if ( $tags_list ) {
				$output .= sprintf( '<span class="tags-links ' . $class . '">%1$s%2$s</span>',
					sprintf( _x( '<span class="screen-reader-text">Tags</span>', 'Used before tag names.', 'helena-pro' ) ),
					$tags_list
				);
			}

			$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

			if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
				$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time><time class="updated" datetime="%3$s">%4$s</time>';
			}

			$time_string = sprintf( $time_string,
				esc_attr( get_the_date( 'c' ) ),
				esc_html( get_the_date() ),
				esc_attr( get_the_modified_date( 'c' ) ),
				esc_html( get_the_modified_date() )
			);

			$class = $hide_posted_by ? 'screen-reader-text' : '';

			$output .= sprintf( '<span class="posted-on ' . $class . '">%1$s<a href="%2$s" rel="bookmark">%3$s</a></span>',
				sprintf( _x( '<span class="screen-reader-text">Posted on</span>', 'Used before publish date.', 'helena-pro' ) ),
				esc_url( get_permalink() ),
				$time_string
			);

			if ( is_singular() || is_multi_author() ) {
				$class = $hide_author ? 'screen-reader-text' : '';

				$output .= sprintf( '<span class="bypostauthor byline ' . $class . '"><span class="author vcard">%1$s<a class="url fn n" href="%2$s">%3$s</a></span></span>',
					sprintf( _x( '<span class="screen-reader-text">Author</span>', 'Used before post author name.', 'helena-pro' ) ),
					esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
					esc_html( get_the_author() )
				);
			}
		}

		$output .= '</p><!-- .entry-meta -->';

		return $output;
	}
endif; //helena_get_meta

/**
 * Display Multiple Select type for and array of categories
 *
 * @param  [string] $name  [field name]
 * @param  [string] $id    [field_id]
 * @param  [array] $selected    [selected values]
 * @param  string $label [label of the field]
 */
function helena_dropdown_categories( $name, $id, $selected, $label = '' ) {
	$dropdown = wp_dropdown_categories(
		array(
			'name'             => $name,
			'echo'             => 0,
			'hide_empty'       => false,
			'show_option_none' => false,
			'hierarchical'       => 1,
		)
	);

	if ( '' != $label ) {
		echo '<label for="' . $id . '">
			'. $label .'
			</label>';
	}

	$dropdown = str_replace('<select', '<select multiple = "multiple" style = "height:120px; width: 100%" ', $dropdown );

	foreach( $selected as $selected ) {
		$dropdown = str_replace( 'value="'. $selected .'"', 'value="'. $selected .'" selected="selected"', $dropdown );
	}

	echo $dropdown;

	echo '<span class="description">'. esc_html__( 'Hold down the Ctrl (windows) / Command (Mac) button to select multiple options.', 'helena-pro' ) . '</span>';
}

/**
 * Flush out all transients
 *
 * @uses delete_transient
 *
 * @action customize_save, helena_customize_preview (see helena_customizer function: helena_customize_preview)
 *
 * @since Helena Pro 1.0
 */
function helena_flush_transients(){
	delete_transient( 'helena_header_highlight_content' );
	delete_transient( 'helena_featured_slider' );
	delete_transient( 'helena_hero_content' );
	delete_transient( 'helena_featured_content' );
	delete_transient( 'helena_portfolio' );
	delete_transient( 'helena_logo_slider' );
	delete_transient( 'helena_custom_css' );
	delete_transient( 'helena_promotion_headline' );
	delete_transient( 'all_the_cool_cats' );
	delete_transient( 'helena_footer_content' );
	delete_transient( 'helena_categories' );
}
add_action( 'customize_save', 'helena_flush_transients' );
add_action( 'customize_preview_init', 'helena_flush_transients' );

if ( ! function_exists( 'helena_page_post_meta' ) ) :
	/**
	 * Post/Page Meta for Google Structure Data
	 */
	function helena_page_post_meta() {
		$helena_author_url = esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) );

		$helena_page_post_meta = '<span class="post-time">' . esc_html__( 'Posted on', 'helena-pro' ) . ' <time class="entry-date updated" datetime="' . esc_attr( get_the_date( 'c' ) ) . '" pubdate>' . esc_html( get_the_date() ) . '</time></span>';
	    $helena_page_post_meta .= '<span class="post-author">' . esc_html__( 'By', 'helena-pro' ) . ' <span class="author vcard"><a class="url fn n" href="' . $helena_author_url . '" title="View all posts by ' . get_the_author() . '" rel="author">' .get_the_author() . '</a></span>';

		return $helena_page_post_meta;
	}
endif; //helena_page_post_meta

if ( ! function_exists( 'helena_truncate_phrase' ) ) :
	/**
	 * Return a phrase shortened in length to a maximum number of characters.
	 *
	 * Result will be truncated at the last white space in the original string. In this function the word separator is a
	 * single space. Other white space characters (like newlines and tabs) are ignored.
	 *
	 * If the first `$max_characters` of the string does not contain a space character, an empty string will be returned.
	 *
	 * @since 2.4.1
	 *
	 * @param string $text            A string to be shortened.
	 * @param integer $max_characters The maximum number of characters to return.
	 *
	 * @return string Truncated string
	 */
	function helena_truncate_phrase( $text, $max_characters ) {
		$text = trim( $text );

		if ( mb_strlen( $text ) > $max_characters ) {
			//* Truncate $text to $max_characters + 1
			$text = mb_substr( $text, 0, $max_characters + 1 );

			//* Truncate to the last space in the truncated string
			$text = trim( mb_substr( $text, 0, mb_strrpos( $text, ' ' ) ) );
		}

		return $text;
	}
endif; //helena_truncate_phrase


if ( ! function_exists( 'helena_get_the_content_limit' ) ) :
	/**
	 * Return content stripped down and limited content.
	 *
	 * Strips out tags and shortcodes, limits the output to `$max_char` characters, and appends an ellipsis and more link to the end.
	 *
	 * @since 2.4.1
	 *
	 * @param integer $max_characters The maximum number of characters to return.
	 * @param string  $more_link_text Optional. Text of the more link. Default is "(more...)" .
	 * @param bool    $stripteaser    Optional. Strip teaser content before the more text. Default is false.
	 *
	 * @return string Limited content.
	 */
	function helena_get_the_content_limit( $max_characters, $more_link_text = '(more...)', $stripteaser = false ) {
		$content = get_the_content( '', $stripteaser );

		//* Strip tags and shortcodes so the content truncation count is done correctly
		$content = strip_tags( strip_shortcodes( $content ), apply_filters( 'get_the_content_limit_allowedtags', '<script>,<style>' ) );

		//* Remove inline styles / scripts
		$content = trim( preg_replace( '#<(s(cript|tyle)).*?</\1>#si', '', $content ) );

		//* Truncate $content to $max_char
		$content = helena_truncate_phrase( $content, $max_characters );

		//* More link?
		if ( $more_link_text ) {
			$link   = apply_filters( 'get_the_content_more_link', sprintf( '<span class="more-button"><a href="%s">%s</a></span>', esc_url ( get_permalink() ), $more_link_text ), $more_link_text );
			$output = sprintf( '<p>%s %s</p>', $content, $link );
		} else {
			$output = sprintf( '<p>%s</p>', $content );
			$link = '';
		}

		return apply_filters( 'helena_get_the_content_limit', $output, $content, $link, $max_characters );

	}
endif; //helena_get_the_content_limit

/**
 * Return the first image in a post. Works inside a loop.
 * @param [integer] $post_id [Post or page id]
 * @param [string/array] $size Image size. Either a string keyword (thumbnail, medium, large or full) or a 2-item array representing width and height in pixels, e.g. array(32,32).
 * @param [string/array] $attr Query string or array of attributes.
 * @return [string] image html
 *
 * @since Helena Pro 1.0
 */

function helena_get_first_image( $postID, $size, $attr ) {
	ob_start();

	ob_end_clean();

	$image 	= '';

	$output = preg_match_all('/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', get_post_field('post_content', $postID ) , $matches);

	if ( isset( $matches [1] [0] ) ) {
		//Get first image
		$first_img = $matches [1] [0];

		return '<img class="pngfix wp-post-image" src="'. $first_img .'">';
	}

	return false;
}

/**
 * Enqueue scripts and styles for Metaboxes
 * @uses wp_register_script, wp_enqueue_script, and  wp_enqueue_style
 *
 * @action admin_print_scripts-post-new, admin_print_scripts-post, admin_print_scripts-page-new, admin_print_scripts-page
 *
 * @since Helena Pro 1.0
 */
function helena_enqueue_metabox_scripts() {
    //Scripts
	wp_enqueue_script( 'helena-metabox', get_template_directory_uri() . '/js/metabox.min.js', array( 'jquery' , 'jquery-ui-tabs' ), '2013-10-05' );

	//CSS Styles
	wp_enqueue_style( 'helena-metabox-tabs', get_template_directory_uri() . '/css/metabox-tabs.css' );
}
add_action( 'admin_print_scripts-post-new.php', 'helena_enqueue_metabox_scripts', 11 );
add_action( 'admin_print_scripts-post.php', 'helena_enqueue_metabox_scripts', 11 );
add_action( 'admin_print_scripts-page-new.php', 'helena_enqueue_metabox_scripts', 11 );
add_action( 'admin_print_scripts-page.php', 'helena_enqueue_metabox_scripts', 11 );

if ( ! function_exists( 'helena_archive_content_image' ) ) :
	/**
	 * Template for Featured Image in Archive Content
	 *
	 * To override this in a child theme
	 * simply create your own helena_archive_content_image(), and that function will be used instead.
	 *
	 * @since Helena Pro 1.0
	 */
	function helena_archive_content_image() {
		$featured_image = apply_filters( 'helena_get_option', 'content_layout' );

		if ( has_post_thumbnail() && 'full-content' != $featured_image ) { ?>
			<a class="post-thumbnail" aria-hidden="true" href="<?php echo esc_url( get_permalink() ); ?>">
				<?php
					the_post_thumbnail( 'post-thumbnail', array( 'alt' => get_the_title() ) );
				?>
			</a>
	   	<?php
		}
	}
endif; //helena_archive_content_image
add_action( 'helena_before_entry_container', 'helena_archive_content_image', 10 );

if ( ! function_exists( 'helena_single_content_image' ) ) :
	/**
	 * Template for Featured Image in Single Post
	 *
	 * To override this in a child theme
	 * simply create your own helena_single_content_image(), and that function will be used instead.
	 *
	 * @since Helena Pro 1.0
	 */
	function helena_single_content_image() {
		global $post, $wp_query;

		// Get Page ID outside Loop
		$page_id = $wp_query->get_queried_object_id();

		if ( $post ) {
	 		if ( is_attachment() ) {
				$parent = $post->post_parent;
				$individual_featured_image = get_post_meta( $parent, 'helena-featured-image', true );
			} else {
				$individual_featured_image = get_post_meta( $page_id, 'helena-featured-image', true );
			}
		}

		if ( empty( $individual_featured_image ) || ( !is_page() && !is_single() ) ) {
			$individual_featured_image = 'default';
		}

		// Getting data from Theme Options
	   	$featured_image = apply_filters( 'helena_get_option', 'single_post_image_layout' );

		if ( ( $individual_featured_image == 'disable' || '' == get_the_post_thumbnail() || ( $individual_featured_image == 'default' && $featured_image == 'disabled') ) ) {
			//Bail if featured image is disabled
			return;
		}

		$class = array();

		if ( 'default' == $individual_featured_image ) {
			$class[] = $featured_image;
		}
		else {
			$class[] = 'from-metabox ';
			$class[] = $featured_image = $individual_featured_image;
		}

		?>
		<div class="entry-thumbnail <?php echo esc_attr( implode( ' ', $class ) ); ?>">
            <?php the_post_thumbnail( $featured_image ); ?>
        </div><!-- .entry-thunbnail -->
	   	<?php
	}
endif; //helena_single_content_image
add_action( 'helena_post_thumbnail', 'helena_single_content_image', 10 );

/**
 * Converts a HEX value to RGB.
 *
 * @since Helena Pro 1.0
 *
 * @param string $color The original color, in 3- or 6-digit hexadecimal form.
 * @return array Array containing RGB (red, green, and blue) values for the given
 *               HEX code, empty array otherwise.
 */
function helena_hex2rgb( $color ) {
	$color = trim( $color, '#' );

	if ( strlen( $color ) === 3 ) {
		$r = hexdec( substr( $color, 0, 1 ).substr( $color, 0, 1 ) );
		$g = hexdec( substr( $color, 1, 1 ).substr( $color, 1, 1 ) );
		$b = hexdec( substr( $color, 2, 1 ).substr( $color, 2, 1 ) );
	} else if ( strlen( $color ) === 6 ) {
		$r = hexdec( substr( $color, 0, 2 ) );
		$g = hexdec( substr( $color, 2, 2 ) );
		$b = hexdec( substr( $color, 4, 2 ) );
	} else {
		return array();
	}

	return array( 'red' => $r, 'green' => $g, 'blue' => $b );
}